==> pipewire-docs-0.2.7-1-arm.pkg.tar.xz: usr/share/doc/pipewire/html/introspect_8c.js <==
var introspect_8c =
[
    [ "pw_client_info_free", "introspect_8c.html#a78bde71750d326423b45f85a8c816eb4", null ],
    [ "pw_client_info_update", "introspect_8c.html#a39b9731b093b364c8700573c0829f0ab", null ],
    [ "pw_core_info_free", "introspect_8c.html#a55ef364dd3066ce9fd9f1895de087d7d", null ],
    [ "pw_core_info_update", "introspect_8c.html#a01d6d6498e373e4751d3ef70328127b2", null ],
    [ "pw_direction_as_string", "introspect_8c.html#aa0ce99661b9419f740e5bb419f763887", null ],
    [ "pw_factory_info_free", "introspect_8c.html#aca143e27dfe58f8748a2e03a411256c5", null ],
    [ "pw_factory_info_update", "introspect_8c.html#ace4050ec98c760baee0b4e06094e6dc2", null ],
    [ "pw_link_info_free", "introspect_8c.html#a2bca5a0b8c7c6a475040c0f803331e08", null ],
    [ "pw_link_info_update", "introspect_8c.html#aba1511432ce4f7eb1ecbd114a007819f", null ],
    [ "pw_link_state_as_string", "introspect_8c.html#a4139b746f150a8c4c4f72704cab51112", null ],
    [ "pw_module_info_free", "introspect_8c.html#acb795a7da145ce0debb5459e6a272ffd", null ],
    [ "pw_module_info_update", "introspect_8c.html#a9026ebd3041fba81c567e0fc5a92a39a", null ],
    [ "pw_node_info_free", "introspect_8c.html#a6a79e5f5e484dd308e74841eeafbd188", null ],
    [ "pw_node_info_update", "introspect_8c.html#a2b1fc4023de9ac5cc30cd92df3aa2c9d", null ],
    [ "pw_node_state_as_string", "introspect_8c.html#a14190b19b22611e5805e8ce04abd21b3", null ],
    [ "pw_port_info_free", "introspect_8c.html#a6075a1328675b49d8000294e5b42e57f", null ],
    [ "pw_port_info_update", "introspect_8c.html#a016723c45876501ddecd292d3f1fc6e8", null ]
];

==> pipewire-docs-0.3.19-1-arm.pkg.tar.xz: usr/share/doc/pipewire/html/introspect_8c.js <==
var introspect_8c =
[
    [ "pw_client_info_free", "introspect_8c.html#a78bde71750d326423b45f85a8c816eb4", null ],
    [ "pw_client_info_update", "introspect_8c.html#a39b9731b093b364c8700573c0829f0ab", null ],
    [ "pw_core_info_free", "introspect_8c.html#a55ef364dd3066ce9fd9f1895de087d7d", null ],
    [ "pw_core_info_update", "introspect_8c.html#a01d6d6498e373e4751d3ef70328127b2", null ],
    [ "pw_device_info_free", "introspect_8c.html#a2e5159416cb78f5da8586daea8a75085", null ],
    [ "pw_device_info_update", "introspect_8c.html#ac03cb9fc4c3e2a5ccf512303022fb6f5", null ],
    [ "pw_direction_as_string", "introspect_8c.html#aaceff23779876a7668c3c2457db64fba", null ],
    [ "pw_factory_info_free", "introspect_8c.html#aca143e27dfe58f8748a2e03a411256c5", null ],
    [ "pw_factory_info_update", "introspect_8c.html#ace4050ec98c760baee0b4e06094e6dc2", null ],
    [ "pw_link_info_free", "introspect_8c.html#a2bca5a0b8c7c6a475040c0f803331e08", null ],
    [ "pw_link_info_update", "introspect_8c.html#aba1511432ce4f7eb1ecbd114a007819f", null ],
    [ "pw_link_state_as_string", "introspect_8c.html#a2aacf740a42ab18e96e0401fd1c30e85", null ],
    [ "pw_module_info_free", "introspect_8c.html#acb795a7da145ce0debb5459e6a272ffd", null ],
    [ "pw_module_info_update", "introspect_8c.html#a9026ebd3041fba81c567e0fc5a92a39a", null ],
    [ "pw_node_info_free", "introspect_8c.html#a6a79e5f5e484dd308e74841eeafbd188", null ],
    [ "pw_node_info_update", "introspect_8c.html#a2b1fc4023de9ac5cc30cd92df3aa2c9d", null ],
    [ "pw_node_state_as_string", "introspect_8c.html#a5cde7af0f47359496cfd6328b3c339b7", null ],
    [ "pw_port_info_free", "introspect_8c.html#a6075a1328675b49d8000294e5b42e57f", null ],
    [ "pw_port_info_update", "introspect_8c.html#a016723c45876501ddecd292d3f1fc6e8", null ]
];
